@@ -127,7 +127,10 @@ class Table(Accessible):
                 if available.
                 """
                 func = self.get_dbus_method("GetColumnHeader", dbus_interface=ATSPI_TABLE)
-                return self._acc_factory (self._app_name, func(index), ATSPI_ACCESSIBLE)
+                (name, path) = func(index)
+                if (name == ""):
+                        name = self._app_name
+                return self._acc_factory (name, path, ATSPI_ACCESSIBLE)
 
         def getIndexAt(self, row, column):
                 """
@@ -308,7 +311,7 @@ class Table(Accessible):
                 @return True if the specified row was successfully de-selected,
                 False if not.
                 """
-                func = self.get_dbus_method("removeRowSelection", dbus_interface=ATSPI_TABLE)
+                func = self.get_dbus_method("RemoveRowSelection", dbus_interface=ATSPI_TABLE)
                 return func(row)
 
         def get_caption(self):
